# coding: utf-8

from sqlalchemy import MetaData, Table, Column, Integer

from migrate.changeset.constraint import ForeignKeyConstraint


def upgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)

    tnx_nodes = Table('tnx_nodes', meta, autoload=True)
    journal = Table('journal', meta, autoload=True)

    for tnx_node in tnx_nodes.select().execute().fetchall():
        # pylint: disable=no-value-for-parameter
        journal.update().where(
            journal.c.tnx_node_id == tnx_node.id
        ).values(object_id=tnx_node.node_id).execute()

    fkey = ForeignKeyConstraint(columns=[journal.c.tnx_node_id],
                                refcolumns=[tnx_nodes.c.id])
    fkey.drop()

    journal.c.tnx_node_id.drop()


def downgrade(migrate_engine):

    meta = MetaData(bind=migrate_engine)

    tnx_nodes = Table('tnx_nodes', meta, autoload=True)
    journal = Table('journal', meta, autoload=True)

    tnx_node_id = Column('node_id', Integer, nullable=False)
    tnx_node_id.create(journal)

    for tnx_node in tnx_nodes.select().execute().fetchall():
        # pylint: disable=no-value-for-parameter
        journal.update().where(
            journal.c.object_id == tnx_node.node_id
        ).values(tnx_node_id=tnx_node.id).execute()

    fkey = ForeignKeyConstraint(columns=[journal.c.tnx_node_id],
                                refcolumns=[tnx_nodes.c.id])
    fkey.create()
