# coding: utf-8
import datetime

from sqlalchemy import (
    MetaData, String, Table, Column, Integer, DateTime)

from migrate.changeset.constraint import ForeignKeyConstraint, UniqueConstraint

from tionix_node_control.fixtures.host_classes import host_classes, host_types


def load_data(meta, fixture):
    model_name = fixture['model']
    data = fixture['data']

    model = Table(model_name, meta, autoload=True)
    # pylint: disable=no-value-for-parameter
    insert = model.insert()
    for d in data:
        kwargs = {
            'id': d['pk'],
            'created_at': datetime.datetime.utcnow(),
            'deleted': 0
        }
        kwargs.update(**d['fields'])
        insert.execute(kwargs)


def upgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)

    host_class_table = Table(
        'host_class', meta,
        Column('id', Integer, primary_key=True),
        Column('created_at', DateTime),
        Column('updated_at', DateTime),
        Column('deleted_at', DateTime),
        Column('deleted', Integer, default=0),
        Column('name', String(25), nullable=False),
        mysql_charset='utf8'
    )
    host_class_table.create()

    uniq = UniqueConstraint('name', 'deleted', table=host_class_table)
    uniq.create()

    host_type_table = Table(
        'host_type', meta,
        Column('id', Integer, primary_key=True),
        Column('created_at', DateTime),
        Column('updated_at', DateTime),
        Column('deleted_at', DateTime),
        Column('deleted', Integer, default=0),
        Column('name', String(50), default=""),
        Column('host_class_id', Integer),
        mysql_charset='utf8'
    )
    host_type_table.create()

    fkey = ForeignKeyConstraint(columns=[host_type_table.c.host_class_id],
                                refcolumns=[host_class_table.c.id],)
    fkey.create()

    load_data(meta, host_classes)
    load_data(meta, host_types)


def downgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)
    Table('host_type', meta, autoload=True).drop()
    Table('host_class', meta, autoload=True).drop()
