# coding: utf-8
from sqlalchemy import MetaData, String, Table, Column, Integer, Text
from migrate.changeset.constraint import ForeignKeyConstraint


def assign_default_host_classes(meta):
    host_class_table = Table('host_class', meta, autoload=True)
    tnx_nodes_table = Table('tnx_nodes', meta, autoload=True)

    def_class_id = host_class_table.select().where(
        host_class_table.c.name == 'hypervisor').execute().first()['id']
    if def_class_id:
        tnx_nodes_table.update().values(host_class_id=def_class_id).execute()


def upgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)

    tnx_nodes_table = Table('tnx_nodes', meta, autoload=True)

    host_class_id = Column(
        'host_class_id',
        Integer,
    )
    host_class_id.create(tnx_nodes_table)

    description = Column('description', Text, nullable=True)
    description.create(tnx_nodes_table)

    cpu_amount = Column('cpu_amount', Integer, nullable=True)
    cpu_amount.create(tnx_nodes_table)

    ram_mb = Column('ram_mb', Integer, nullable=True)
    ram_mb.create(tnx_nodes_table)

    hdd_gb = Column('hdd_gb', Integer, nullable=True)
    hdd_gb.create(tnx_nodes_table)

    ip_addresses_table = Table(
        'tnx_ip_addresses', meta,
        Column('id', Integer, primary_key=True),
        Column('ip_address', String(25), nullable=False),
        Column('tnx_node_id', Integer, nullable=False)
    )
    ip_addresses_table.create()

    node_id_fk = ForeignKeyConstraint(
        columns=[ip_addresses_table.c.tnx_node_id],
        refcolumns=[tnx_nodes_table.c.id],
        ondelete="CASCADE",
    )
    node_id_fk.create()

    host_class_table = Table('host_class', meta, autoload=True)
    host_class_id_fk = ForeignKeyConstraint(
        columns=[tnx_nodes_table.c.host_class_id],
        refcolumns=[host_class_table.c.id],
    )
    host_class_id_fk.create()

    assign_default_host_classes(meta)


def downgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)

    ip_addresses_table = Table('tnx_ip_addresses', meta, autoload=True)
    tnx_nodes_table = Table('tnx_nodes', meta, autoload=True)
    host_class_table = Table('host_class', meta, autoload=True)

    ForeignKeyConstraint(
        columns=[ip_addresses_table.c.tnx_node_id],
        refcolumns=[tnx_nodes_table.c.id],
        ondelete="CASCADE",
    ).drop()

    ForeignKeyConstraint(
        columns=[tnx_nodes_table.c.host_class_id],
        refcolumns=[host_class_table.c.id],
    ).drop()

    tnx_nodes_table.c.host_class_id.drop()
    tnx_nodes_table.c.description.drop()
    tnx_nodes_table.c.cpu_amount.drop()
    tnx_nodes_table.c.ram_mb.drop()
    tnx_nodes_table.c.hdd_gb.drop()
    ip_addresses_table.drop()
