# coding: utf-8

import logging

from sqlalchemy import MetaData, Table, and_
from tionix_client.os_clients.nova_client import get_nova_client

from tionix_node_control.settings import CONF

logger = logging.getLogger(__name__)


def get_nova_hypervisors():
    nova_client = get_nova_client(
        username=CONF.KEYSTONE['auth_user'],
        password=CONF.KEYSTONE['auth_password'],
        tenant=CONF.KEYSTONE['auth_tenant'])
    return {h.id: h for h in nova_client.hypervisors.list()}


# noinspection PyComparisonWithNone
def upgrade(migrate_engine):
    """
    Set host class, host type and ip address to all hosts related to Nova node.
    """
    meta = MetaData(bind=migrate_engine)

    tnx_nodes = Table('tnx_nodes', meta, autoload=True)
    host_type = Table('host_type', meta, autoload=True)
    host_class = Table('host_class', meta, autoload=True)
    tnx_ip_addresses = Table('tnx_ip_addresses', meta, autoload=True)

    # pylint: disable=no-value-for-parameter, singleton-comparison
    has_node_id_no_class_no_type = and_(
        tnx_nodes.c.node_id != None,  # noqa
        tnx_nodes.c.host_class_id == None,
        tnx_nodes.c.host_type_id == None
    )
    nodes_to_update = tnx_nodes.select(has_node_id_no_class_no_type).execute()
    if nodes_to_update.rowcount:
        nova_hypervisors = get_nova_hypervisors()

        host_class_hypervisor = host_class.select(
            host_class.c.name == 'Hypervisor').execute().first()
        host_type_qemu = host_type.select(
            host_type.c.name == 'QEMU').execute().first()

        for node in nodes_to_update:
            with migrate_engine.begin() as con:
                #  update nodes with defaults
                con.execute(
                    tnx_nodes.update().values(
                        host_class_id=host_class_hypervisor.id,
                        host_type_id=host_type_qemu.id
                    ).where(
                        tnx_nodes.c.node_id == node.node_id
                    )
                )

                # insert nodes ip address
                hypervisor_matched = nova_hypervisors[int(node.node_id)]
                con.execute(
                    tnx_ip_addresses.insert().values(
                        ip_address=hypervisor_matched.host_ip,
                        tnx_node_id=node.id
                    )
                )


# noinspection PyUnusedLocal
def downgrade(migrate_engine):
    pass
