# coding: utf-8

from sqlalchemy import (
    MetaData, Table, Column, Integer, Boolean, String, DateTime, Text)


def upgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)

    shadow_aggregates = Table(
        'shadow_aggregates', meta,
        Column('id', Integer, primary_key=True, nullable=False),
        Column('created_at', DateTime),
        Column('updated_at', DateTime),
        Column('deleted_at', DateTime),
        Column('deleted', Integer),
        Column('aggregate_id', String(36), nullable=False),
        Column('allow_balancing', Boolean, nullable=False, default=False))
    shadow_aggregates.create()

    host_class_table = Table(
        'shadow_host_class', meta,
        Column('id', Integer, primary_key=True),
        Column('created_at', DateTime),
        Column('updated_at', DateTime),
        Column('deleted_at', DateTime),
        Column('deleted', Integer, default=0),
        Column('name', String(25), nullable=False),
        mysql_charset='utf8'
    )
    host_class_table.create()

    host_type_table = Table(
        'shadow_host_type', meta,
        Column('id', Integer, primary_key=True),
        Column('created_at', DateTime),
        Column('updated_at', DateTime),
        Column('deleted_at', DateTime),
        Column('deleted', Integer, default=0),
        Column('name', String(50), default=""),
        Column('host_class_id', Integer),
        mysql_charset='utf8'
    )
    host_type_table.create()

    node_reserv_table = Table(
        'shadow_node_reservs', meta,
        Column('id', Integer, primary_key=True, nullable=False),
        Column('created_at', DateTime),
        Column('updated_at', DateTime),
        Column('deleted_at', DateTime),
        Column('deleted', Integer, default=0),
        Column('tnx_node_id', Integer),
        Column('reserv_tnx_node_id', Integer)
    )
    node_reserv_table.create()

    ip_addresses_table = Table(
        'shadow_tnx_ip_addresses', meta,
        Column('id', Integer, primary_key=True),
        Column('created_at', DateTime),
        Column('updated_at', DateTime),
        Column('deleted_at', DateTime),
        Column('deleted', Integer, default=0),
        Column('ip_address', String(25), nullable=False),
        Column('tnx_node_id', Integer, nullable=False)
    )
    ip_addresses_table.create()

    tnx_nodes = Table(
        'shadow_tnx_nodes', meta,
        Column('created_at', DateTime),
        Column('updated_at', DateTime),
        Column('deleted_at', DateTime),
        Column('deleted', Integer),
        Column('id', Integer, primary_key=True),
        Column('image_id', Integer, nullable=False),
        Column('dtc_number', Integer),
        Column('unit_number', Integer),
        Column('rack_number', Integer),
        Column('node_title', String(100), nullable=True),
        Column('node_id', String(255)),
        Column('node_name', String(255)),
        Column('is_controller', Boolean),
        Column('node_mac_address', String(18)),
        Column('is_reserved', Boolean, default=False),
        Column('inventory_code', String(128), nullable=True),
        Column('power_state', String(10), nullable=True),
        Column('host_class_id', Integer),
        Column('description', Text, nullable=True),
        Column('cpu_amount', Integer, nullable=True),
        Column('ram_mb', Integer, nullable=True),
        Column('hdd_gb', Integer, nullable=True),
        Column('host_type_id', Integer, nullable=True),
        Column('controller_id', String(36), default=None, nullable=True),
        Column('controller_login', String(255), nullable=True),
        Column('controller_password', String(128), nullable=True),
        Column('controller_type', String(50), nullable=True),
        Column('row_number', Integer, nullable=True),
        Column('owner', String(length=255), nullable=True),
        Column('condition', Integer, nullable=False, default=0),
        Column('active', Boolean, nullable=False, default=True),
        mysql_charset='utf8'
    )
    tnx_nodes.create()

    tnx_node_devices = Table(
        'shadow_tnx_node_devices', meta,
        Column('created_at', DateTime),
        Column('updated_at', DateTime),
        Column('deleted_at', DateTime),
        Column('deleted', Integer),
        Column('id', Integer, primary_key=True),
        Column('is_default', Boolean, default=False),
        Column('tnx_node_id', Integer, nullable=False),
        Column('power_device_id', Integer, nullable=False),
        Column('node_port', String(10)),
        Column('is_initialized', Boolean, default=True),
        mysql_charset='utf8'
    )
    tnx_node_devices.create()

    tnx_node_images = Table(
        'shadow_tnx_node_images', meta,
        Column('created_at', DateTime),
        Column('updated_at', DateTime),
        Column('deleted_at', DateTime),
        Column('deleted', Integer),
        Column('id', Integer, primary_key=True, nullable=False),
        Column('image_name', String(35)),
        Column('file_data', String(511)),
        mysql_charset='utf8'
    )
    tnx_node_images.create()

    tnx_power_control_history_table = Table(
        'shadow_tnx_power_control_history', meta,
        Column('id', Integer, primary_key=True, nullable=False),
        Column('created_at', DateTime),
        Column('updated_at', DateTime),
        Column('deleted_at', DateTime),
        Column('deleted', Integer),
        Column('tnx_node_id', Integer),
        Column('image_id', Integer),
        Column('action', String(100)),
        Column('active', Boolean(), default=True),
        Column('user_name', String(100))
    )
    tnx_power_control_history_table.create()

    tnx_power_devices = Table(
        'shadow_tnx_power_devices', meta,
        Column('created_at', DateTime),
        Column('updated_at', DateTime),
        Column('deleted_at', DateTime),
        Column('deleted', Integer),
        Column('title', String(50), nullable=True),
        Column('ssh_key', Text(), nullable=True),
        Column('id', Integer, primary_key=True),
        Column('device_name', String(127)),
        Column('protocol_type', String(63)),
        Column('host', String(255)),
        Column('port_number', Integer),
        Column('login', String(63)),
        Column('password', String(63)),
        mysql_charset='utf8'
    )
    tnx_power_devices.create()


def downgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)
    servers_table = Table('aggregates', meta)
    servers_table.drop()
